diff a/src/hotspot/share/cds/dumpAllocStats.cpp b/src/hotspot/share/cds/dumpAllocStats.cpp
--- a/src/hotspot/share/cds/dumpAllocStats.cpp
+++ b/src/hotspot/share/cds/dumpAllocStats.cpp
@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2020, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2020, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 only, as
  * published by the Free Software Foundation.
@@ -21,10 +21,12 @@
  * questions.
  *
  */
 
 #include "precompiled.hpp"
+#include "cds/cdsConfig.hpp"
+#include "cds/classPreloader.hpp"
 #include "cds/dumpAllocStats.hpp"
 #include "logging/log.hpp"
 #include "logging/logMessage.hpp"
 
 void DumpAllocStats::print_stats(int ro_all, int rw_all) {
@@ -100,10 +102,26 @@
          "everything should have been counted (used/counted: ro %d/%d, rw %d/%d",
          ro_all, all_ro_bytes, rw_all, all_rw_bytes);
 
 #undef fmt_stats
 
-  msg.debug("Class CP entries = %d, archived = %d (%3.1f%%)",
-            _num_klass_cp_entries, _num_klass_cp_entries_archived,
-            percent_of(_num_klass_cp_entries_archived, _num_klass_cp_entries));
-
+  msg.info("Class  CP entries = %6d, archived = %6d (%5.1f%%), excluded = %6d",
+           _num_klass_cp_entries, _num_klass_cp_entries_archived,
+           percent_of(_num_klass_cp_entries_archived, _num_klass_cp_entries),
+           _num_klass_cp_entries_excluded);
+  msg.info("Field  CP entries = %6d, archived = %6d (%5.1f%%), excluded = %6d",
+           _num_field_cp_entries, _num_field_cp_entries_archived,
+           percent_of(_num_field_cp_entries_archived, _num_field_cp_entries),
+           _num_field_cp_entries_excluded);
+  msg.info("Method CP entries = %6d, archived = %6d (%5.1f%%), excluded = %6d",
+           _num_method_cp_entries, _num_method_cp_entries_archived,
+           percent_of(_num_method_cp_entries_archived, _num_method_cp_entries),
+           _num_method_cp_entries_excluded);
+  msg.info("Indy   CP entries = %6d, archived = %6d (%5.1f%%), excluded = %6d",
+           _num_indy_cp_entries, _num_indy_cp_entries_archived,
+           percent_of(_num_indy_cp_entries_archived, _num_indy_cp_entries),
+           _num_indy_cp_entries_excluded);
+  msg.info("Platform loader initiated classes = %5d", ClassPreloader::num_platform_initiated_classes());
+  msg.info("App      loader initiated classes = %5d", ClassPreloader::num_app_initiated_classes());
+  msg.info("Dynamic proxy classes             = %5d%s", _num_dynamic_proxy_classes,
+           CDSConfig::is_dumping_full_module_graph() ? "" : " (not archiving FMG)");
 }
